@@ -1,39 +1,11 @@
 from platon import Web3
 from platon.datastructures import AttributeDict
 
-from platon_aide.economic import Economic
-from platon_aide.module import Module
+from platon_aide.economic import Economic, new_economic
+from platon_aide.base.module import Module
 from platon_aide.utils import contract_transaction
 
 
-class _StakingInfo(AttributeDict):
-    """ 质押信息的属性字典类
-    """
-    NodeId: str
-    StakingAddress: str
-    BenefitAddress: str
-    RewardPer: int
-    NextRewardPer: int
-    StakingTxIndex: int
-    ProgramVersion: int
-    Status: int
-    StakingEpoch: int
-    StakingBlockNum: int
-    Shares: int
-    Released: int
-    ReleasedHes: int
-    RestrictingPlan: int
-    RestrictingPlanHes: int
-    ExternalId: int
-    NodeName: str
-    Website: str
-    Details: str
-    DelegateEpoch: int
-    DelegateTotal: int
-    DelegateTotalHes: int
-    DelegateRewardTotal: int
-
-
 class Staking(Module):
     _node_id: str
     _bls_pubkey: str
@@ -46,7 +18,7 @@ class Staking(Module):
         self._module_type = 'inner-contract'
         self._result_type = 'event'
         self._get_node_info()
-        self._economic = economic if economic else Economic(web3)
+        self._economic = new_economic(web3.debug.economic_config()) if not economic and hasattr(web3, 'debug') else economic
 
     @property
     def staking_info(self):
@@ -127,15 +99,15 @@ class Staking(Module):
 
     def get_verifier_list(self):
         verifier_list = self.web3.ppos.staking.get_verifier_list()
-        return [_StakingInfo(verifier) for verifier in verifier_list]
+        return [StakingInfo(verifier) for verifier in verifier_list]
 
     def get_validator_list(self):
         validator_list = self.web3.ppos.staking.get_validator_list()
-        return [_StakingInfo(validator) for validator in validator_list]
+        return [StakingInfo(validator) for validator in validator_list]
 
     def get_candidate_list(self):
         candidate_list = self.web3.ppos.staking.get_candidate_list()
-        return [_StakingInfo(candidate) for candidate in candidate_list]
+        return [StakingInfo(candidate) for candidate in candidate_list]
 
     def get_candidate_info(self, node_id=None):
         node_id = node_id or self._node_id
@@ -143,7 +115,7 @@ class Staking(Module):
         if staking_info == 'Query candidate info failed:Candidate info is not found':
             return None
         else:
-            return _StakingInfo(staking_info)
+            return StakingInfo(staking_info)
 
     def get_block_reward(self):
         return self.web3.ppos.staking.get_block_reward()
@@ -153,3 +125,31 @@ class Staking(Module):
 
     def get_avg_block_time(self):
         return self.web3.ppos.staking.get_avg_block_time()
+
+
+class StakingInfo(AttributeDict):
+    """ 质押信息的属性字典类
+    """
+    NodeId: str
+    StakingAddress: str
+    BenefitAddress: str
+    RewardPer: int
+    NextRewardPer: int
+    StakingTxIndex: int
+    ProgramVersion: int
+    Status: int
+    StakingEpoch: int
+    StakingBlockNum: int
+    Shares: int
+    Released: int
+    ReleasedHes: int
+    RestrictingPlan: int
+    RestrictingPlanHes: int
+    ExternalId: int
+    NodeName: str
+    Website: str
+    Details: str
+    DelegateEpoch: int
+    DelegateTotal: int
+    DelegateTotalHes: int
+    DelegateRewardTotal: int
